import"./outputWidgets.6d6b4a37.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="11230dbc-164c-4086-a6b7-face296cc1ed",e._sentryDebugIdIdentifier="sentry-dbid-11230dbc-164c-4086-a6b7-face296cc1ed")}catch{}})();const d=e=>{try{return new URL(e),!0}catch{return!1}};export{d as i};
//# sourceMappingURL=url.b5fbb423.js.map
