import{t,b as s,eu as o}from"./outputWidgets.6d6b4a37.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="aae1fd48-6f5f-458b-9eec-4c223357be38",e._sentryDebugIdIdentifier="sentry-dbid-aae1fd48-6f5f-458b-9eec-4c223357be38")}catch{}})();const r={},a={class:"organization-settings"};function i(e,n){return s(),o("div",a,"Organization settings")}const f=t(r,[["render",i]]);export{f as default};
//# sourceMappingURL=OrganizationSettings.892c7530.js.map
