import{_ as C}from"./logo.084e5d7c.js";import{t as B,b as r,eu as y,eD as I,eE as w,e as h,d as k,ez as L,a as D,u as e,c,bx as S,w as t,f as o,az as l,eC as i,bX as f,cG as b,cC as N,eJ as V,eB as E,eY as R,b6 as z,ew as P}from"./outputWidgets.6d6b4a37.js";import{a as g}from"./router.4e9df257.js";import{a as T}from"./asyncComputed.17a6198d.js";import{A as $,B as j,a as F,c as G}from"./index.838a4574.js";import{c as H}from"./index.0e216cc8.js";(function(){try{var a=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},s=new Error().stack;s&&(a._sentryDebugIds=a._sentryDebugIds||{},a._sentryDebugIds[s]="99517eda-1107-4f07-ac49-a2114144af0a",a._sentryDebugIdIdentifier="sentry-dbid-99517eda-1107-4f07-ac49-a2114144af0a")}catch{}})();const J={},v=a=>(I("data-v-439be421"),a=a(),w(),a),M={class:"logo"},U=v(()=>h("img",{class:"logo-img",src:C,alt:"Abstra cloud logo"},null,-1)),X=v(()=>h("span",null,"Abstra Cloud",-1)),Y=[U,X];function q(a,s){return r(),y("div",M,Y)}const K=B(J,[["render",q],["__scopeId","data-v-439be421"]]),O=k({__name:"LoginBlock",setup(a){function s(p){const m=p.split("@")[0];return V.exports.kebabCase(m).toUpperCase().split("-").slice(0,2).map(_=>_[0]).join("")}const u=L(),{result:n,loading:d,refetch:x}=T(async()=>g.getAuthor());function A(){g.removeAuthor(),x(),u.push({name:"login"})}return(p,m)=>{const _=D("router-link");return e(d)?(r(),c(e(S),{key:0})):e(n)?(r(),c(e(N),{key:1,placement:"bottomRight"},{content:t(()=>[o(e(b),{direction:"vertical"},{default:t(()=>[o(e(H),null,{default:t(()=>[l(i(e(n).claims.email),1)]),_:1}),o(e(f),{onClick:A},{default:t(()=>[l("Logout")]),_:1})]),_:1})]),default:t(()=>[o(e(b),{align:"center",style:{cursor:"pointer"}},{default:t(()=>[o(e($),null,{default:t(()=>[l(i(s(e(n).claims.email)),1)]),_:1})]),_:1})]),_:1})):(r(),c(e(f),{key:2},{default:t(()=>[o(_,{to:"/login"},{default:t(()=>[l("Login")]),_:1})]),_:1}))}}}),oe=k({__name:"Navbar",props:{breadcrumb:{}},setup(a){return(s,u)=>(r(),c(e(G),{style:{padding:"5px 10px"}},{breadcrumb:t(()=>[s.breadcrumb?(r(),c(e(j),{key:0},{default:t(()=>[(r(!0),y(z,null,E(s.breadcrumb,(n,d)=>(r(),c(e(F),{key:d},{default:t(()=>[o(e(R),{to:n.path},{default:t(()=>[l(i(n.label),1)]),_:2},1032,["to"])]),_:2},1024))),128))]),_:1})):P("",!0)]),title:t(()=>[o(K)]),extra:t(()=>[o(O)]),_:1}))}});export{oe as _};
//# sourceMappingURL=Navbar.vue_vue_type_script_setup_true_lang.ec54cfd7.js.map
