[data-v-fe2ede96]:root{--main-font-family: DM Sans, sans-serif}[data-v-fe2ede96]:root{--abstra-neutral-color: #bbb;--abstra-primary-color: #ffee56;--abstra-dark-text-color: #1b1b23;--abstra-normal-text-color: #414a58;--abstra-main-color-dark: #343b46;--abstra-main-color-light: #ffd84c;--abstra-secondary-color-dark: #4c5767;--abstra-secondary-color-light: #feab4c;--abstra-background-base: #f9fafb;--abstra-main-color-blue: #d14056}.p-dropdown[data-v-fe2ede96]{border-radius:8px;border:1px solid #343b46;background-color:#fff;height:37px;padding:0 10px;align-items:center}.p-dropdown-panel[data-v-fe2ede96]{background-color:#fff;padding:10px}.sidebar[data-v-fe2ede96]{height:100%;box-sizing:border-box;display:flex;flex-direction:column;gap:28px;overflow:auto}@media screen and (min-width: 600px){.sidebar[data-v-fe2ede96]{min-width:200px}}.sidebar .section[data-v-fe2ede96]{display:flex;flex-direction:column;min-width:160px;gap:10px;color:#6d7c93;font-weight:500;font-size:.65rem;text-transform:uppercase}.sidebar .item[data-v-fe2ede96]{padding:6px 10px;width:100%;box-sizing:border-box;display:flex;gap:10px;align-items:center;border-radius:.5rem;border-radius:8px;color:#4e596a;fill:#4e596a;text-transform:initial;font-weight:500;font-size:.8rem}.sidebar .item[data-v-fe2ede96]:not(.disabled):not(.active):not(:active){cursor:pointer}.sidebar .item .warning[data-v-fe2ede96]{margin-left:auto;display:flex;align-items:center;justify-content:center}.sidebar .item .tag[data-v-fe2ede96]{display:block;font-size:8px;color:#fff;padding:4px;border-radius:5px}.sidebar .item .tag.beta[data-v-fe2ede96]{background-color:#d56d6d}.sidebar .item .tag.soon[data-v-fe2ede96]{background-color:#c8c8c8}.sidebar .item .tag.cloud[data-v-fe2ede96]{background-color:#a5b2ff}.sidebar .item .icon[data-v-fe2ede96] path{fill:#4e596a}.sidebar .item.disabled[data-v-fe2ede96]{color:#bbb}.sidebar .item.disabled .icon[data-v-fe2ede96] path{fill:#bbb}.sidebar .item .item-name[data-v-fe2ede96]{font-size:14px;font-weight:500;line-height:16px;letter-spacing:0em}.sidebar .item[data-v-fe2ede96]:hover:not(.disabled):not(.active):not(:active){background:#ffffff;color:#343b46;font-weight:600;box-shadow:0 0 15px #0000000a}.sidebar .item:hover:not(.disabled):not(.active):not(:active) .icon[data-v-fe2ede96] path{fill:#343b46}.sidebar .item[data-v-fe2ede96]:active:not(.disabled),.sidebar .item.active[data-v-fe2ede96]{background:#edeff2;color:#292f37;font-weight:700}.sidebar .item:active:not(.disabled) .icon[data-v-fe2ede96] path,.sidebar .item.active .icon[data-v-fe2ede96] path{fill:#292f37}@media screen and (max-width: 600px){.sidebar .section-name[data-v-fe2ede96],.sidebar .item-name[data-v-fe2ede96]{display:none}.sidebar .section[data-v-fe2ede96]{min-width:34px;min-height:34px}.sidebar .section[data-v-fe2ede96],.sidebar .sidebar[data-v-fe2ede96]{gap:10px}.sidebar .item[data-v-fe2ede96]{flex-direction:column;gap:0}}.logo[data-v-81cd596e]{display:flex;align-items:center}.logo img[data-v-81cd596e]{height:30px}.logo span[data-v-81cd596e]{font-size:18px;font-weight:600;margin-left:10px}
