import{d as k,ez as B,eA as D,r as N,G as $,b as a,eu as o,b6 as f,eB as b,e as _,eC as g,ey as v,f as n,I as y,ew as l,c as x,w as s,u as m,t as I,eD as L,eE as T,a as w,bX as A,az as E}from"./outputWidgets.6d6b4a37.js";import{f as O,h as V,j,c as z,m as R,p as F,w as H}from"./icons.28d0d847.js";import{T as P}from"./Tooltip.9ad0fee6.js";import{_ as W}from"./logo.084e5d7c.js";import{B as q}from"./BaseLayout.5a0efef2.js";import{N as G}from"./NavbarControls.f407b84f.js";import{c as J}from"./index.838a4574.js";import"./workspaces.ed4248fb.js";import"./record.7835c07e.js";import"./pubsub.7d377b25.js";import"./url.b5fbb423.js";import"./popupNotifcation.fbd53de0.js";import"./asyncComputed.17a6198d.js";import"./index.ec217461.js";import"./SaveButton.vue_vue_type_script_setup_true_lang.18978e4d.js";import"./ant-design.c99b7781.js";import"./index.f2a53bdb.js";import"./Title.b41b4f96.js";import"./index.0e216cc8.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[r]="145903ad-c1c6-4679-a2c4-57935a76da58",t._sentryDebugIdIdentifier="sentry-dbid-145903ad-c1c6-4679-a2c4-57935a76da58")}catch{}})();const U={class:"sidebar"},X={class:"section-name"},K=["onClick"],M={class:"item-name"},Q={key:0,class:"tag soon"},Y={key:1,class:"tag beta"},Z={key:2,class:"tag cloud"},ee=k({__name:"Sidebar",setup(t){var h;const r=B(),u=D(),c=N((h=u.name)!=null?h:"forms"),p=$(()=>[{name:"Runtime",items:[{name:"Forms",icon:O,path:"forms"},{name:"Hooks",icon:V,path:"hooks"},{name:"Jobs",icon:j,path:"jobs",cloud:!0}]},{name:"Settings",items:[{name:"Style",icon:z,path:"style"},{name:"Sidebar",icon:R,path:"sidebar"},{name:"Packages",icon:F,path:"requirements"}]}]),C=i=>{i.unavailable||(r.push(i.path),c.value=i.path)};return(i,de)=>(a(),o("div",U,[(a(!0),o(f,null,b(p.value,d=>(a(),o("div",{key:d.name,class:"section"},[_("span",X,g(d.name),1),(a(!0),o(f,null,b(d.items,e=>(a(),o("div",{key:e.name,role:"button",class:v(["item",{active:c.value===e.path,disabled:e.unavailable||d.cloud}]),tabindex:"0",onClick:le=>C(e)},[n(y,{class:v(["icon",{disabled:e.unavailable,active:c.value===e.path}]),path:e.icon,width:"20",height:"20"},null,8,["class","path"]),_("span",M,g(e.name),1),e.unavailable?(a(),o("span",Q,"SOON")):l("",!0),e.beta?(a(),o("span",Y,"BETA")):l("",!0),e.cloud?(a(),o("span",Z,"CLOUD")):l("",!0),e.warning?(a(),x(P,{key:3,class:"warning",text:e.warning,fixed:!0,top:18,left:18},{default:s(()=>[n(y,{path:m(H),fill:"#D35249",width:"20",height:"20"},null,8,["path"])]),_:2},1032,["text"])):l("",!0)],10,K))),128))]))),128))]))}});const te=I(ee,[["__scopeId","data-v-fe2ede96"]]);const ae={},S=t=>(L("data-v-81cd596e"),t=t(),T(),t),oe={class:"logo"},se=S(()=>_("img",{src:W,alt:"Abstra cloud logo"},null,-1)),ne=S(()=>_("span",null," Abstra ",-1)),re=[se,ne];function ce(t,r){return a(),o("div",oe,re)}const ie=I(ae,[["render",ce],["__scopeId","data-v-81cd596e"]]),$e=k({__name:"Workspace",setup(t){return(r,u)=>{const c=w("router-link"),p=w("router-view");return a(),x(q,null,{navbar:s(()=>[n(m(J),{style:{padding:"5px 10px"}},{title:s(()=>[n(ie)]),extra:s(()=>[n(G,{"show-github-stars":""},{default:s(()=>[n(c,{to:{name:"workflowEditor"}},{default:s(()=>[n(m(A),null,{default:s(()=>[E("Workflow editor")]),_:1})]),_:1})]),_:1})]),_:1})]),sidebar:s(()=>[n(te,{class:"sidebar"})]),content:s(()=>[n(p)]),_:1})}}});export{$e as default};
//# sourceMappingURL=Workspace.b0bfdba7.js.map
