import{d,eA as b,G as l,a as g,b as f,c as v,w as r,f as s}from"./outputWidgets.6d6b4a37.js";import{B as h}from"./BaseLayout.5a0efef2.js";import{a as _}from"./asyncComputed.17a6198d.js";import"./router.4e9df257.js";import"./index.2cafcd9c.js";import{P as y}from"./project.c406c3ff.js";import{O as z}from"./organization.f89e67cc.js";import{_ as j}from"./Navbar.vue_vue_type_script_setup_true_lang.ec54cfd7.js";import{S as I}from"./Sidebar.aea49d6d.js";import{y as w,z as k,A as B,B as C,C as P,D as $,q as x,E as D,F as L,u as M,v as O,x as S}from"./icons.28d0d847.js";import"./Form.1ff54ed5.js";import"./index.72c317ca.js";import"./record.7835c07e.js";import"./pubsub.7d377b25.js";import"./gateway.7a58b0c8.js";import"./logo.084e5d7c.js";import"./index.838a4574.js";import"./Title.b41b4f96.js";import"./index.0e216cc8.js";import"./Tooltip.9ad0fee6.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},i=new Error().stack;i&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[i]="96bca2f8-7add-46f6-b96c-1e8e3e0fb295",o._sentryDebugIdIdentifier="sentry-dbid-96bca2f8-7add-46f6-b96c-1e8e3e0fb295")}catch{}})();const oa=d({__name:"Project",setup(o){const c=b().params.projectId,{result:a}=_(()=>y.get(c).then(async e=>{const t=await z.get(e.organizationId);return{project:e,organization:t}})),m=l(()=>{var e,t,n,p;return((e=a.value)==null?void 0:e.organization)&&a.value.project?[{label:"My organizations",path:"/organizations"},{label:(n=(t=a.value)==null?void 0:t.organization)==null?void 0:n.name,path:`/organizations/${(p=a.value)==null?void 0:p.organization.id}`},{label:a.value.project.name,path:`/projects/${a.value.project.id}`}]:void 0}),u=l(()=>{var e;return(e=a.value)!=null&&e.project?[{name:"Project",items:[{name:"Live",path:"live",icon:w},{name:"Builds",path:"builds",icon:k},{name:"Connectors",path:"connectors",icon:B},{name:"Tables",path:"tables",icon:C},{name:"API Keys",path:"api-keys",icon:P},{name:"Env Vars",path:"env-vars",icon:$},{name:"Files",path:"files",icon:x},{name:"Logs",icon:D,path:"logs",beta:!0},{name:"Settings",icon:L,path:"settings"}]},{name:"Organization",items:[{name:"Projects",icon:M,path:`/organizations/${a.value.project.organizationId}/projects`},{name:"Members",icon:O,path:`/organizations/${a.value.project.organizationId}/members`},{name:"Billing",icon:S,path:`/organizations/${a.value.project.organizationId}/billing`,unavailable:!0}]}]:[]});return(e,t)=>{const n=g("router-view");return f(),v(h,null,{content:r(()=>[s(n)]),navbar:r(()=>[s(j,{class:"nav",breadcrumb:m.value},null,8,["breadcrumb"])]),sidebar:r(()=>[s(I,{class:"sidebar",sections:u.value},null,8,["sections"])]),_:1})}}});export{oa as default};
//# sourceMappingURL=Project.20bae68f.js.map
