import{d as _,$ as P,L as D,G as y,f as d,a5 as c,aG as A,bv as E,z as G,B as V,U as B,Z as R,ag as F,a$ as Q,da as U,N as w,Q as W}from"./outputWidgets.6d6b4a37.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},i=new Error().stack;i&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[i]="51ba423f-48e3-467c-9031-5f6f49bdcefd",e._sentryDebugIdIdentifier="sentry-dbid-51ba423f-48e3-467c-9031-5f6f49bdcefd")}catch{}})();var Z={icon:{tag:"svg",attrs:{viewBox:"64 64 896 896",focusable:"false"},children:[{tag:"path",attrs:{d:"M908.1 353.1l-253.9-36.9L540.7 86.1c-3.1-6.3-8.2-11.4-14.5-14.5-15.8-7.8-35-1.3-42.9 14.5L369.8 316.2l-253.9 36.9c-7 1-13.4 4.3-18.3 9.3a32.05 32.05 0 00.6 45.3l183.7 179.1-43.4 252.9a31.95 31.95 0 0046.4 33.7L512 754l227.1 119.4c6.2 3.3 13.4 4.4 20.3 3.2 17.4-3 29.1-19.5 26.1-36.9l-43.4-252.9 183.7-179.1c5-4.9 8.3-11.3 9.3-18.3 2.7-17.5-9.5-33.7-27-36.3z"}}]},name:"star",theme:"filled"};const ee=Z,q=()=>({prefixCls:String,color:String,dot:c.any,pending:A(),position:c.oneOf(E("left","right","")).def(""),label:c.any}),S=_({compatConfig:{MODE:3},name:"ATimelineItem",props:P(q(),{color:"blue",pending:!1}),slots:Object,setup(e,i){let{slots:l}=i;const{prefixCls:a}=D("timeline",e),t=y(()=>({[`${a.value}-item`]:!0,[`${a.value}-item-pending`]:e.pending})),g=y(()=>/blue|red|green|gray/.test(e.color||"")?void 0:e.color||"blue"),v=y(()=>({[`${a.value}-item-head`]:!0,[`${a.value}-item-head-${e.color||"blue"}`]:!g.value}));return()=>{var u,p,r;const{label:o=(u=l.label)===null||u===void 0?void 0:u.call(l),dot:n=(p=l.dot)===null||p===void 0?void 0:p.call(l)}=e;return d("li",{class:t.value},[o&&d("div",{class:`${a.value}-item-label`},[o]),d("div",{class:`${a.value}-item-tail`},null),d("div",{class:[v.value,!!n&&`${a.value}-item-head-custom`],style:{borderColor:g.value,color:g.value}},[n]),d("div",{class:`${a.value}-item-content`},[(r=l.default)===null||r===void 0?void 0:r.call(l)])])}}}),J=e=>{const{componentCls:i}=e;return{[i]:B(B({},R(e)),{margin:0,padding:0,listStyle:"none",[`${i}-item`]:{position:"relative",margin:0,paddingBottom:e.timeLineItemPaddingBottom,fontSize:e.fontSize,listStyle:"none","&-tail":{position:"absolute",insetBlockStart:e.timeLineItemHeadSize,insetInlineStart:(e.timeLineItemHeadSize-e.timeLineItemTailWidth)/2,height:`calc(100% - ${e.timeLineItemHeadSize}px)`,borderInlineStart:`${e.timeLineItemTailWidth}px ${e.lineType} ${e.colorSplit}`},"&-pending":{[`${i}-item-head`]:{fontSize:e.fontSizeSM,backgroundColor:"transparent"},[`${i}-item-tail`]:{display:"none"}},"&-head":{position:"absolute",width:e.timeLineItemHeadSize,height:e.timeLineItemHeadSize,backgroundColor:e.colorBgContainer,border:`${e.timeLineHeadBorderWidth}px ${e.lineType} transparent`,borderRadius:"50%","&-blue":{color:e.colorPrimary,borderColor:e.colorPrimary},"&-red":{color:e.colorError,borderColor:e.colorError},"&-green":{color:e.colorSuccess,borderColor:e.colorSuccess},"&-gray":{color:e.colorTextDisabled,borderColor:e.colorTextDisabled}},"&-head-custom":{position:"absolute",insetBlockStart:e.timeLineItemHeadSize/2,insetInlineStart:e.timeLineItemHeadSize/2,width:"auto",height:"auto",marginBlockStart:0,paddingBlock:e.timeLineItemCustomHeadPaddingVertical,lineHeight:1,textAlign:"center",border:0,borderRadius:0,transform:"translate(-50%, -50%)"},"&-content":{position:"relative",insetBlockStart:-(e.fontSize*e.lineHeight-e.fontSize)+e.lineWidth,marginInlineStart:e.margin+e.timeLineItemHeadSize,marginInlineEnd:0,marginBlockStart:0,marginBlockEnd:0,wordBreak:"break-word"},"&-last":{[`> ${i}-item-tail`]:{display:"none"},[`> ${i}-item-content`]:{minHeight:e.controlHeightLG*1.2}}},[`&${i}-alternate,
        &${i}-right,
        &${i}-label`]:{[`${i}-item`]:{"&-tail, &-head, &-head-custom":{insetInlineStart:"50%"},"&-head":{marginInlineStart:`-${e.marginXXS}px`,"&-custom":{marginInlineStart:e.timeLineItemTailWidth/2}},"&-left":{[`${i}-item-content`]:{insetInlineStart:`calc(50% - ${e.marginXXS}px)`,width:`calc(50% - ${e.marginSM}px)`,textAlign:"start"}},"&-right":{[`${i}-item-content`]:{width:`calc(50% - ${e.marginSM}px)`,margin:0,textAlign:"end"}}}},[`&${i}-right`]:{[`${i}-item-right`]:{[`${i}-item-tail,
            ${i}-item-head,
            ${i}-item-head-custom`]:{insetInlineStart:`calc(100% - ${(e.timeLineItemHeadSize+e.timeLineItemTailWidth)/2}px)`},[`${i}-item-content`]:{width:`calc(100% - ${e.timeLineItemHeadSize+e.marginXS}px)`}}},[`&${i}-pending
        ${i}-item-last
        ${i}-item-tail`]:{display:"block",height:`calc(100% - ${e.margin}px)`,borderInlineStart:`${e.timeLineItemTailWidth}px dotted ${e.colorSplit}`},[`&${i}-reverse
        ${i}-item-last
        ${i}-item-tail`]:{display:"none"},[`&${i}-reverse ${i}-item-pending`]:{[`${i}-item-tail`]:{insetBlockStart:e.margin,display:"block",height:`calc(100% - ${e.margin}px)`,borderInlineStart:`${e.timeLineItemTailWidth}px dotted ${e.colorSplit}`},[`${i}-item-content`]:{minHeight:e.controlHeightLG*1.2}},[`&${i}-label`]:{[`${i}-item-label`]:{position:"absolute",insetBlockStart:-(e.fontSize*e.lineHeight-e.fontSize)+e.timeLineItemTailWidth,width:`calc(50% - ${e.marginSM}px)`,textAlign:"end"},[`${i}-item-right`]:{[`${i}-item-label`]:{insetInlineStart:`calc(50% + ${e.marginSM}px)`,width:`calc(50% - ${e.marginSM}px)`,textAlign:"start"}}},"&-rtl":{direction:"rtl",[`${i}-item-head-custom`]:{transform:"translate(50%, -50%)"}}})}},K=G("Timeline",e=>{const i=V(e,{timeLineItemPaddingBottom:e.padding*1.25,timeLineItemHeadSize:10,timeLineItemCustomHeadPaddingVertical:e.paddingXXS,timeLinePaddingInlineEnd:2,timeLineItemTailWidth:e.lineWidthBold,timeLineHeadBorderWidth:e.wireframe?e.lineWidthBold:e.lineWidth*3});return[J(i)]}),Y=()=>({prefixCls:String,pending:c.any,pendingDot:c.any,reverse:A(),mode:c.oneOf(E("left","alternate","right",""))}),f=_({compatConfig:{MODE:3},name:"ATimeline",inheritAttrs:!1,props:P(Y(),{reverse:!1,mode:""}),slots:Object,setup(e,i){let{slots:l,attrs:a}=i;const{prefixCls:t,direction:g}=D("timeline",e),[v,u]=K(t),p=(r,o)=>{const n=r.props||{};return e.mode==="alternate"?n.position==="right"?`${t.value}-item-right`:n.position==="left"?`${t.value}-item-left`:o%2===0?`${t.value}-item-left`:`${t.value}-item-right`:e.mode==="left"?`${t.value}-item-left`:e.mode==="right"?`${t.value}-item-right`:n.position==="right"?`${t.value}-item-right`:""};return()=>{var r,o,n;const{pending:m=(r=l.pending)===null||r===void 0?void 0:r.call(l),pendingDot:M=(o=l.pendingDot)===null||o===void 0?void 0:o.call(l),reverse:b,mode:C}=e,N=typeof m=="boolean"?null:m,I=F((n=l.default)===null||n===void 0?void 0:n.call(l)),x=m?d(S,{pending:!!m,dot:M||d(Q,null,null)},{default:()=>[N]}):null;x&&I.push(x);const L=b?I.reverse():I,H=L.length,T=`${t.value}-item-last`,O=L.map(($,s)=>{const h=s===H-2?T:"",j=s===H-1?T:"";return U($,{class:w([!b&&!!m?h:j,p($,s)])})}),z=L.some($=>{var s,h;return!!(((s=$.props)===null||s===void 0?void 0:s.label)||((h=$.children)===null||h===void 0?void 0:h.label))}),X=w(t.value,{[`${t.value}-pending`]:!!m,[`${t.value}-reverse`]:!!b,[`${t.value}-${C}`]:!!C&&!z,[`${t.value}-label`]:z,[`${t.value}-rtl`]:g.value==="rtl"},a.class,u.value);return v(d("ul",W(W({},a),{},{class:X}),[O]))}}});f.Item=S;f.install=function(e){return e.component(f.name,f),e.component(S.name,S),e};export{S as A,ee as S,f as T};
//# sourceMappingURL=index.1c6494ef.js.map
