import{cA as n}from"./outputWidgets.6d6b4a37.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[r]="6f359590-2017-479e-8235-689e769670fd",e._sentryDebugIdIdentifier="sentry-dbid-6f359590-2017-479e-8235-689e769670fd")}catch{}})();const d=(e,r)=>{n.error({message:e,description:r})};export{d as p};
//# sourceMappingURL=popupNotifcation.fbd53de0.js.map
