import"./outputWidgets.6d6b4a37.js";import"./index.f2a53bdb.js";import{M as n}from"./Title.b41b4f96.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[e]="509481c7-4548-483d-9f4a-1ee25e36e90a",t._sentryDebugIdIdentifier="sentry-dbid-509481c7-4548-483d-9f4a-1ee25e36e90a")}catch{}})();function f(t){switch(typeof t){case"object":return Object.entries(t).map(([e,r])=>({title:e,key:e,children:f(r)}));default:return[{title:t,key:t}]}}function i(t,e){return new Promise(r=>{n.confirm({title:t,onOk:()=>r(!0),okText:e==null?void 0:e.okText,onCancel:()=>r(!1),cancelText:e==null?void 0:e.cancelText})})}export{i as a,f as t};
//# sourceMappingURL=ant-design.c99b7781.js.map
