import{S as p}from"./Sidebar.aea49d6d.js";import{_ as c}from"./Navbar.vue_vue_type_script_setup_true_lang.ec54cfd7.js";import{u as d,v as l,x as u}from"./icons.28d0d847.js";import{d as b,eA as f,G as g,a as _,b as y,c as v,w as t,f as r}from"./outputWidgets.6d6b4a37.js";import{a as w}from"./asyncComputed.17a6198d.js";import"./router.4e9df257.js";import"./index.2cafcd9c.js";import{O as z}from"./organization.f89e67cc.js";import{B as h}from"./BaseLayout.5a0efef2.js";import"./Tooltip.9ad0fee6.js";import"./logo.084e5d7c.js";import"./index.838a4574.js";import"./Title.b41b4f96.js";import"./index.0e216cc8.js";import"./Form.1ff54ed5.js";import"./index.72c317ca.js";import"./record.7835c07e.js";import"./pubsub.7d377b25.js";import"./gateway.7a58b0c8.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="ec611661-d458-47be-9aa2-d3663cd6645b",e._sentryDebugIdIdentifier="sentry-dbid-ec611661-d458-47be-9aa2-d3663cd6645b")}catch{}})();const H=b({__name:"Organization",setup(e){const n=f().params.organizationId,{result:a}=w(()=>z.get(n)),i=g(()=>a.value?[{label:"My organizations",path:"/organizations"},{label:a.value.name,path:`/organizations/${a.value.id}`}]:void 0),s=[{name:"Organization",items:[{name:"Projects",icon:d,path:"projects"},{name:"Members",icon:l,path:"members"},{name:"Billing",icon:u,path:"billing",unavailable:!0}]}];return(I,B)=>{const m=_("router-view");return y(),v(h,null,{navbar:t(()=>[r(c,{breadcrumb:i.value},null,8,["breadcrumb"])]),sidebar:t(()=>[r(p,{class:"sidebar",sections:s})]),content:t(()=>[r(m)]),_:1})}}});export{H as default};
//# sourceMappingURL=Organization.a510362e.js.map
