[data-v-bd751ecc]:root{--main-font-family: DM Sans, sans-serif}[data-v-bd751ecc]:root{--abstra-neutral-color: #bbb;--abstra-primary-color: #ffee56;--abstra-dark-text-color: #1b1b23;--abstra-normal-text-color: #414a58;--abstra-main-color-dark: #343b46;--abstra-main-color-light: #ffd84c;--abstra-secondary-color-dark: #4c5767;--abstra-secondary-color-light: #feab4c;--abstra-background-base: #f9fafb;--abstra-main-color-blue: #d14056}.p-dropdown[data-v-bd751ecc]{border-radius:8px;border:1px solid #343b46;background-color:#fff;height:37px;padding:0 10px;align-items:center}.p-dropdown-panel[data-v-bd751ecc]{background-color:#fff;padding:10px}.oi[data-v-bd751ecc]{display:flex;flex-direction:column}.oi .oi-item[data-v-bd751ecc]{display:flex;align-items:center;margin-bottom:5px}.oi .oi-item .oi-item-label[data-v-bd751ecc]{font-size:16px;font-weight:500;margin-right:5px;border:1px solid #d6d6d6;border-radius:4px;padding:8px 12px}.oi .oi-item .oi-item-input[data-v-bd751ecc]{flex:1}[data-v-a6c8b9fb]:root{--main-font-family: DM Sans, sans-serif}[data-v-a6c8b9fb]:root{--abstra-neutral-color: #bbb;--abstra-primary-color: #ffee56;--abstra-dark-text-color: #1b1b23;--abstra-normal-text-color: #414a58;--abstra-main-color-dark: #343b46;--abstra-main-color-light: #ffd84c;--abstra-secondary-color-dark: #4c5767;--abstra-secondary-color-light: #feab4c;--abstra-background-base: #f9fafb;--abstra-main-color-blue: #d14056}.p-dropdown[data-v-a6c8b9fb]{border-radius:8px;border:1px solid #343b46;background-color:#fff;height:37px;padding:0 10px;align-items:center}.p-dropdown-panel[data-v-a6c8b9fb]{background-color:#fff;padding:10px}.ai[data-v-a6c8b9fb]{display:flex;flex-direction:column}.ai .ai-item[data-v-a6c8b9fb]{display:flex;align-items:center;margin-bottom:5px}.ai .ai-item .gi[data-v-a6c8b9fb]{flex:1}.ai .ai-item .ai-item-remove[data-v-a6c8b9fb]{margin-left:5px;border:none;background:none;color:gray;cursor:pointer}.ai .ai-item .ai-item-remove[data-v-a6c8b9fb]:hover{color:red}.ai .ai-item-add[data-v-a6c8b9fb]{margin-top:5px;border:none;background:none;color:gray;cursor:pointer}.ai .ai-item-add[data-v-a6c8b9fb]:hover{color:green}[data-v-dd33d764]:root{--main-font-family: DM Sans, sans-serif}[data-v-dd33d764]:root{--abstra-neutral-color: #bbb;--abstra-primary-color: #ffee56;--abstra-dark-text-color: #1b1b23;--abstra-normal-text-color: #414a58;--abstra-main-color-dark: #343b46;--abstra-main-color-light: #ffd84c;--abstra-secondary-color-dark: #4c5767;--abstra-secondary-color-light: #feab4c;--abstra-background-base: #f9fafb;--abstra-main-color-blue: #d14056}.p-dropdown[data-v-dd33d764]{border-radius:8px;border:1px solid #343b46;background-color:#fff;height:37px;padding:0 10px;align-items:center}.p-dropdown-panel[data-v-dd33d764]{background-color:#fff;padding:10px}.gi .gi-header[data-v-dd33d764]{display:flex;align-items:center;justify-content:space-between;margin-bottom:5px}.gi .gi-header .gi-label[data-v-dd33d764]{font-size:16px;font-weight:500}.gi .gi-header .gi-tags[data-v-dd33d764]{display:flex;align-items:center}.gi .gi-header .gi-tags .gi-required[data-v-dd33d764],.gi .gi-header .gi-tags .gi-secret[data-v-dd33d764]{font-size:12px;color:gray}.gi .gi-description[data-v-dd33d764]{font-size:14px;margin-bottom:10px}.gi .gi-input[data-v-dd33d764]{border:1px solid #d6d6d6;border-radius:4px;padding:8px 12px;font-size:14px;color:#6d7c93;font-family:DM Sans,sans-serif;outline:none;width:100%;box-sizing:border-box;transition:all .2s ease-in-out}.gi .gi-input[data-v-dd33d764]:focus{border:1px solid #d14056}
