import{d as b,eA as u,G as f,b as y,c as g,u as _}from"./outputWidgets.6d6b4a37.js";import{a as w}from"./asyncComputed.17a6198d.js";import"./router.4e9df257.js";import"./index.2cafcd9c.js";import{M as n}from"./member.cf6af74f.js";import{C as I}from"./CrudView.230a173f.js";import"./Form.1ff54ed5.js";import"./index.72c317ca.js";import"./record.7835c07e.js";import"./pubsub.7d377b25.js";import"./gateway.7a58b0c8.js";import"./icons.28d0d847.js";import"./index.0e216cc8.js";import"./Title.b41b4f96.js";import"./url.b5fbb423.js";import"./index.9eddb8ae.js";import"./index.6f6e8ffd.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="da7c6bb2-717a-4f14-bd53-cf6827f5a8ab",e._sentryDebugIdIdentifier="sentry-dbid-da7c6bb2-717a-4f14-bd53-cf6827f5a8ab")}catch{}})();const j=b({__name:"Members",setup(e){const a=u().params.organizationId,m=[{key:"email",label:"Email"}],s=async t=>{await n.create(a,t.email),c()},{loading:l,result:d,refetch:c}=w(()=>n.list(a)),p=f(()=>{var t,r;return{columns:[{name:"Email"},{name:"Role"}],rows:(r=(t=d.value)==null?void 0:t.map(i=>({key:i.email,cells:[{text:i.email},{text:i.role}]})))!=null?r:[]}});return(t,r)=>(y(),g(I,{"entity-name":"members",loading:_(l),title:"Organization members",description:"List all organization members.","empty-title":"No members yet",table:p.value,"create-button-text":"Add members",fields:m,onCreate:s},null,8,["loading","table"]))}});export{j as default};
//# sourceMappingURL=Members.5c2aa676.js.map
